@@ -1,5 +1,5 @@
 # -*- coding utf-8 -*-
-# Copyright (C) 2020 Greenbone Networks GmbH
+# Copyright (C) 2020-2021 Greenbone Networks GmbH
 #
 # SPDX-License-Identifier GPL-3.0-or-later
 #
@@ -20,6 +20,10 @@
 
 from .test_create_note import GmpCreateNoteTestCase
 from .test_create_override import GmpCreateOverrideTestCase
+from .test_create_target import GmpCreateTargetTestCase
 from .test_modify_note import GmpModifyNoteTestCase
 from .test_modify_override import GmpModifyOverrideTestCase
+from .test_modify_target import GmpModifyTargetTestCase
 from .test_modify_user import GmpModifyUserTestCase
+from .test_create_scanner import GmpCreateScannerTestCase
+from .test_modify_scanner import GmpModifyScannerTestCase
